==> qttools-6.10.1-r1-3.gpkg.tar: image/usr/src/debug/dev-qt/qttools-6.10.1-r1/qttools-everywhere-src-6.10.1_build/src/designer/src/components/lib/.qt/rcc/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // fontmapping.xml
  0x0,0x0,0x1,0x3a,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x4f,0x8,0x85,0x9,0x0,0x52,0xcf,0x32,0x20,0x10,0x95,0x1e,
  0xc7,0x25,0x42,0x96,0x14,0x92,0x7d,0xf8,0xa2,0xa0,0xb8,0xb9,0xa3,0xa,0xfa,0x6a,
  0x26,0xcf,0x8c,0x28,0x3b,0xca,0xa2,0x33,0x1,0x0,0x54,0xc1,0xd,0x71,0xea,0xb7,
  0xb8,0x9d,0xaf,0xb7,0xb7,0xeb,0x82,0xab,0xfa,0xf1,0xc5,0xf,0x8f,0x32,0xca,0x8d,
  0xe2,0x41,0x2,0x8d,0xcf,0x2e,0x7b,0x95,0xca,0x28,0xbd,0x3b,0x2b,0x1e,0xb2,0xcc,
  0xcf,0x5f,0xd5,0xd7,0x55,0x3b,0x39,0x59,0x79,0x1b,0xfa,0x94,0x3e,0xc7,0x62,0xa0,
  0xca,0x3,0x98,0xe5,0x9e,0x8,0xd3,0x5b,0x2f,0x1,0xff,0xcd,0x33,0x5a,0xa6,0x41,
  0x30,0x8d,0xd4,0xb9,0x35,0xe7,0x69,0xf7,0xc5,0x9c,0x63,0x92,0x8c,0x66,0x45,0x2e,
  0x80,0x94,0xa4,0xa,0x42,0x89,0x9a,0xa,0xf0,0xe2,0xba,0xf3,0x6f,0xa3,0xf7,0x86,
  0x96,0x5d,0xfc,0xeb,0x2e,0x86,0xd4,0x74,0x80,0xe,0x9,0xc3,0x29,0x11,0xef,0x66,
  0xdd,0xf4,0x5b,0xb8,0x27,0x90,0x7b,0x8a,0x27,0xf4,0x57,0xae,0xee,0xfb,0x34,0x83,
  0xef,0xdd,0xdf,0xaa,0x3,0x62,0x2e,0x49,0x65,0xa2,0xdb,0xe1,0xdf,0x9d,0xd9,0xee,
  0x89,0xbf,0x47,0x73,0x44,0x81,0x32,0x38,0xc1,0x1a,0xf8,0xf6,0x74,0xaa,0xfe,0x32,
  0xb6,0x3c,0x46,0x9,0x42,0x80,0xc,0x24,0x20,0x20,0x42,0x2,0xa5,0x55,0x38,0x6,
  0x5d,0x48,0x96,0x80,0x3a,0x5,0x49,0xa,0xc8,0x96,0x86,0x43,0x19,0x15,0xda,0x40,
  0xd0,0x7a,0xd,0x6c,0x68,0x2a,0x20,0x48,0x0,0x9c,0x6a,0x7d,0xd1,0x54,0x10,0x72,
  0x81,0x57,0x4d,0x4f,0x22,0xa,0xca,0x2e,0xe8,0x86,0xaa,0x81,0xad,0x82,0x93,0xc3,
  0xcf,0x7b,0x40,0x8f,0x71,0x21,0xb7,0xcf,0x40,0x2,0xae,0xc1,0xc2,0x3a,0xee,0xab,
  0x80,0x6f,0xd,0x8,0xc0,0xc5,0xdb,0x86,0x56,0x50,0x34,0x58,0x99,0x81,0xac,0x7,
  0xbb,0x3b,0x47,0xc3,0xea,0x69,0x0,0x3f,0x1,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x7e,0xef,0x8d,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qttools-6.10.2-1.gpkg.tar: image/usr/src/debug/dev-qt/qttools-6.10.2/qttools-everywhere-src-6.10.2_build/src/designer/src/components/lib/.qt/rcc/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // fontmapping.xml
  0x0,0x0,0x1,0x3a,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x4f,0x8,0x85,0x9,0x0,0x52,0xcf,0x32,0x20,0x10,0x95,0x1e,
  0xc7,0x25,0x42,0x96,0x14,0x92,0x7d,0xf8,0xa2,0xa0,0xb8,0xb9,0xa3,0xa,0xfa,0x6a,
  0x26,0xcf,0x8c,0x28,0x3b,0xca,0xa2,0x33,0x1,0x0,0x54,0xc1,0xd,0x71,0xea,0xb7,
  0xb8,0x9d,0xaf,0xb7,0xb7,0xeb,0x82,0xab,0xfa,0xf1,0xc5,0xf,0x8f,0x32,0xca,0x8d,
  0xe2,0x41,0x2,0x8d,0xcf,0x2e,0x7b,0x95,0xca,0x28,0xbd,0x3b,0x2b,0x1e,0xb2,0xcc,
  0xcf,0x5f,0xd5,0xd7,0x55,0x3b,0x39,0x59,0x79,0x1b,0xfa,0x94,0x3e,0xc7,0x62,0xa0,
  0xca,0x3,0x98,0xe5,0x9e,0x8,0xd3,0x5b,0x2f,0x1,0xff,0xcd,0x33,0x5a,0xa6,0x41,
  0x30,0x8d,0xd4,0xb9,0x35,0xe7,0x69,0xf7,0xc5,0x9c,0x63,0x92,0x8c,0x66,0x45,0x2e,
  0x80,0x94,0xa4,0xa,0x42,0x89,0x9a,0xa,0xf0,0xe2,0xba,0xf3,0x6f,0xa3,0xf7,0x86,
  0x96,0x5d,0xfc,0xeb,0x2e,0x86,0xd4,0x74,0x80,0xe,0x9,0xc3,0x29,0x11,0xef,0x66,
  0xdd,0xf4,0x5b,0xb8,0x27,0x90,0x7b,0x8a,0x27,0xf4,0x57,0xae,0xee,0xfb,0x34,0x83,
  0xef,0xdd,0xdf,0xaa,0x3,0x62,0x2e,0x49,0x65,0xa2,0xdb,0xe1,0xdf,0x9d,0xd9,0xee,
  0x89,0xbf,0x47,0x73,0x44,0x81,0x32,0x38,0xc1,0x1a,0xf8,0xf6,0x74,0xaa,0xfe,0x32,
  0xb6,0x3c,0x46,0x9,0x42,0x80,0xc,0x24,0x20,0x20,0x42,0x2,0xa5,0x55,0x38,0x6,
  0x5d,0x48,0x96,0x80,0x3a,0x5,0x49,0xa,0xc8,0x96,0x86,0x43,0x19,0x15,0xda,0x40,
  0xd0,0x7a,0xd,0x6c,0x68,0x2a,0x20,0x48,0x0,0x9c,0x6a,0x7d,0xd1,0x54,0x10,0x72,
  0x81,0x57,0x4d,0x4f,0x22,0xa,0xca,0x2e,0xe8,0x86,0xaa,0x81,0xad,0x82,0x93,0xc3,
  0xcf,0x7b,0x40,0x8f,0x71,0x21,0xb7,0xcf,0x40,0x2,0xae,0xc1,0xc2,0x3a,0xee,0xab,
  0x80,0x6f,0xd,0x8,0xc0,0xc5,0xdb,0x86,0x56,0x50,0x34,0x58,0x99,0x81,0xac,0x7,
  0xbb,0x3b,0x47,0xc3,0xea,0x69,0x0,0x3f,0x1,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xda,0x9a,0x35,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
